@@ -18,6 +18,7 @@ typedef enum {
 	CAMEL_STUB_CMD_GET_TRASH_NAME,
 	CAMEL_STUB_CMD_SYNC_FOLDER,
 	CAMEL_STUB_CMD_REFRESH_FOLDER,
+	CAMEL_STUB_CMD_SYNC_COUNT,
 	CAMEL_STUB_CMD_EXPUNGE_UIDS,
 	CAMEL_STUB_CMD_APPEND_MESSAGE,
 	CAMEL_STUB_CMD_SET_MESSAGE_FLAGS,
@@ -79,7 +80,9 @@ typedef enum {
 	CAMEL_STUB_FOLDER_SYSTEM      = (1<<6),
 	CAMEL_STUB_FOLDER_TYPE_INBOX  = (1<<7),
 	CAMEL_STUB_FOLDER_SUBSCRIBED  = (1<<8),
-	CAMEL_STUB_FOLDER_NOCHILDREN  = (1<<9)
+	CAMEL_STUB_FOLDER_NOCHILDREN  = (1<<9),
+	CAMEL_STUB_FOLDER_TYPE_TRASH  = (1<<10),
+	CAMEL_STUB_FOLDER_TYPE_SENT   = (1<<11)
 } CamelStubFolderFlags;
 
 typedef enum {
